import { ObservableArray, ChangedData, Color } from '@nativescript/core';
import * as chartInitializersCommon from '../initializers/chart-initializers.common';
import * as chartCommonModule from '../common';
import { CartesianAxis, CategoricalAxis } from '../visualization/views/chart-axis.common';
import { RadLegendView } from '../visualization/views/chart-legend-view.common';
import { Palette } from '../visualization/parts/chart-palette.common';
import { PointLabelStyle } from '../visualization/parts/chart-label-style.common';
import { ChartAxisLabelFitMode, ChartAxisHorizontalLocation, ChartAxisVerticalLocation, ChartAxisPlotMode, ChartAxisLabelVisibility, ChartSeriesPaletteMode, ChartSeriesSelectionMode, ChartSeriesStackMode } from '../misc/chart-public-enum';
import { ScatterSeries, ChartSeries, CartesianSeries, BubbleSeries, OhlcSeries, CandlestickSeries, RangeBarSeries, CategoricalSeries, ScatterBubbleSeries, PieSeries, DonutSeries, BarSeries } from '../visualization/views/chart-series.common';
export declare class ChartBaseValueMapper implements chartInitializersCommon.ChartBaseValueMapper {
    private _currentChart;
    onLegendChanged(oldValue: RadLegendView, newValue: RadLegendView, chart: chartCommonModule.RadChartBase): void;
    onPalettesChanged(data: ChangedData<any>, chart: chartCommonModule.RadChartBase): void;
    onPalettesPropertyChanged(oldValue: ObservableArray<Palette>, newValue: ObservableArray<Palette>, chart: chartCommonModule.RadChartBase): void;
    private loadPalette;
    private getPalettesForSeries;
    private applyPalettesToSeries;
    private buildNewPaletteForSeries;
    private getPaletteEntryIndexForSeries;
    onSeriesChanged(data: ChangedData<any>, chart: chartCommonModule.RadChartBase): void;
    onSeriesPropertyChanged(oldValue: ObservableArray<any>, newValue: ObservableArray<any>, chart: chartCommonModule.RadChartBase): void;
    loadSeries(chart: chartCommonModule.RadChartBase): void;
    reloadPalettes(chart: chartCommonModule.RadChartBase): void;
    loadAnnotations(chart: chartCommonModule.RadChartBase): void;
    onAnnotationsChanged(data: ChangedData<any>, chart: chartCommonModule.RadChartBase): void;
    onAnnotationsPropertyChanged(oldValue: ObservableArray<any>, newValue: ObservableArray<any>, chart: chartCommonModule.RadChartBase): void;
    private resolveVerticalAxisForSeries;
}
export declare class CartesianAxisValueMapper implements chartInitializersCommon.CartesianAxisValueMapper {
    onLineThicknessChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onLineColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onLineHiddenChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    onLabelTextColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onLabelBackgroundColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onLabelBorderColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onLabelBorderWidthChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onLabelMarginChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onLabelRotationAngleChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onLabelFitModeChanged(oldValue: ChartAxisLabelFitMode, newValue: ChartAxisLabelFitMode, axis: CartesianAxis): void;
    onLabelLayoutModeChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onLabelFormatChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onTicksHiddenChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    onTicksThicknessChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onTicksLengthChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onTicksOffsetChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onTicksColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onHorizontalLocationChanged(oldValue: ChartAxisHorizontalLocation, newValue: ChartAxisHorizontalLocation, axis: CartesianAxis): void;
    onVerticalLocationChanged(oldValue: ChartAxisVerticalLocation, newValue: ChartAxisVerticalLocation, axis: CartesianAxis): void;
    onFontInternalChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onLabelPaddingChanged(newValue: number, propertyName: string, axis: CartesianAxis): void;
    onLabelSizeChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onAllowZoomChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    onAllowPanChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    private updatePanZoomBehavior;
    onHiddenChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
}
export declare class CategoricalAxisValueMapper extends CartesianAxisValueMapper implements chartInitializersCommon.CategoricalAxisValueMapper {
    onMajorTickIntervalChanged(oldValue: number, newValue: number, axis: CategoricalAxis): void;
    onPlotModeChanged(oldValue: ChartAxisPlotMode, newValue: ChartAxisPlotMode, axis: CategoricalAxis): void;
    onLastLabelVisibilityChanged(oldValue: ChartAxisLabelVisibility, newValue: ChartAxisLabelVisibility, axis: CategoricalAxis): void;
    onFirstLabelVisibilityChanged(oldValue: ChartAxisLabelVisibility, newValue: ChartAxisLabelVisibility, axis: CategoricalAxis): void;
}
export declare class ChartSeriesValueMapper implements chartInitializersCommon.ChartSeriesValueMapper {
    onShowLabelsChanged(oldValue: boolean, newValue: boolean, series: ChartSeries): void;
    onLegendTitleChanged(newValue: string, series: ChartSeries): void;
    onLabelPaddingChanged(newValue: number, propertyName: string, series: ChartSeries): void;
    onItemsChanged(oldValue: any, newValue: any, series: ChartSeries): void;
    onValuePropertyChanged(oldValue: any, newValue: any, series: ChartSeries): void;
    onLabelStyleChanged(oldValue: PointLabelStyle, newValue: PointLabelStyle, series: ChartSeries): void;
    onSelectionModeChanged(oldValue: ChartSeriesSelectionMode, newValue: ChartSeriesSelectionMode, series: ChartSeries): void;
    onFontInternalChanged(oldValue: any, newValue: any, series: ChartSeries): void;
    private applyFontInternal;
    applyLabelStyle(series: ChartSeries, chart?: any): void;
}
export declare class CartesianSeriesValueMapper extends ChartSeriesValueMapper implements chartInitializersCommon.CartesianSeriesValueMapper {
    onHorizontalAxisChanged(oldValue: CartesianAxis, newValue: CartesianAxis, series: CartesianSeries): void;
    onVerticalAxisChanged(oldValue: CartesianAxis, newValue: CartesianAxis, series: CartesianSeries): void;
    onItemsChanged(oldValue: any, newValue: any, series: ChartSeries): void;
    onPaletteModeChanged(oldValue: ChartSeriesPaletteMode, newValue: ChartSeriesPaletteMode, series: CartesianSeries): void;
    onFillColorChanged(oldValue: Color, newValue: Color, series: CartesianSeries): void;
    onStrokeWidthChanged(oldValue: number, newValue: number, series: CartesianSeries): void;
    onStrokeColorChanged(oldValue: Color, newValue: Color, series: CartesianSeries): void;
}
export declare class ScatterSeriesValueMapper extends CartesianSeriesValueMapper implements chartInitializersCommon.ScatterSeriesValueMapper {
    onXPropertyChanged(oldValue: string, newValue: string, series: ScatterSeries): void;
    onYPropertyChanged(oldValue: string, newValue: string, series: ScatterSeries): void;
}
export declare class ScatterBubbleSeriesValueMapper extends ScatterSeriesValueMapper implements chartInitializersCommon.ScatterBubbleSeriesValueMapper {
    onBubbleSizePropertyChanged(oldValue: string, newValue: string, series: ScatterBubbleSeries): void;
    onBubbleScaleChanged(oldValue: number, newValue: number, series: ScatterBubbleSeries): void;
}
export declare class CategoricalSeriesValueMapper extends CartesianSeriesValueMapper implements chartInitializersCommon.CategoricalSeriesValueMapper {
    updateNative(series: CategoricalSeries): void;
    onCategoryPropertyChanged(oldValue: string, newValue: string, series: CategoricalSeries): void;
    onStackModePropertyChanged(oldValue: ChartSeriesStackMode, newValue: ChartSeriesStackMode, series: CategoricalSeries): void;
}
export declare class BarSeriesValueMapper extends CategoricalSeriesValueMapper implements chartInitializersCommon.BarSeriesValueMapper {
    onMinBarSizeChanged(oldValue: number, newValue: number, series: BarSeries): void;
    onMaxBarSizeChanged(oldValue: number, newValue: number, series: BarSeries): void;
}
export declare class PieSeriesValueMapper extends ChartSeriesValueMapper implements chartInitializersCommon.PieSeriesValueMapper {
    onLabelPropertyChanged(oldValue: string, newValue: string, series: PieSeries): void;
    onLegendTitleChanged(newValue: string, series: PieSeries): void;
    onExpandRadiusChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onOuterRadiusFactorChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onStartAngleChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onEndAngleChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onShowPercentageChanged(oldValue: boolean, newValue: boolean, series: PieSeries): void;
    onFillColorsChanged(oldValue: Color[], newValue: Color[], series: PieSeries): void;
    onStrokeWidthChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onStrokeColorsChanged(oldValue: Color[], newValue: Color[], series: PieSeries): void;
    private applyColors;
}
export declare class DonutSeriesValueMapper extends PieSeriesValueMapper implements chartInitializersCommon.DonutSeriesValueMapper {
    onInnerRadiusFactorChanged(oldValue: any, newValue: any, series: DonutSeries): void;
}
export declare class RangeBarSeriesValueMapper extends CategoricalSeriesValueMapper {
    onHighPropertyNameChanged(oldValue: string, newValue: string, series: RangeBarSeries): void;
    onLowPropertyNameChanged(oldValue: string, newValue: string, series: RangeBarSeries): void;
}
export declare class LineSeriesValueMapper extends CategoricalSeriesValueMapper {
    onPaletteModeChanged(oldValue: string, newValue: string, series: CartesianSeries): void;
    onFillColorChanged(oldValue: Color, newValue: Color, series: ChartSeries): void;
}
export declare class SplineSeriesValueMapper extends LineSeriesValueMapper implements chartInitializersCommon.SplineSeriesValueMapper {
}
export declare class AreaSeriesValueMapper extends LineSeriesValueMapper {
    onFillColorChanged(oldValue: Color, newValue: Color, series: ChartSeries): void;
}
export declare class SplineAreaSeriesValueMapper extends AreaSeriesValueMapper {
}
export declare class OhlcSeriesValueMapper extends CategoricalSeriesValueMapper {
    onHighPropertyNameChanged(oldValue: string, newValue: string, series: OhlcSeries): void;
    onLowPropertyNameChanged(oldValue: string, newValue: string, series: OhlcSeries): void;
    onOpenPropertyNameChanged(oldValue: string, newValue: string, series: OhlcSeries): void;
    onClosePropertyNameChanged(oldValue: string, newValue: string, series: OhlcSeries): void;
    onFillColorChanged(oldValue: Color, newValue: Color, series: ChartSeries): void;
    onStrokeColorsChanged(oldValue: Color[], newValue: Color[], series: OhlcSeries): void;
}
export declare class CandlestickSeriesValueMapper extends OhlcSeriesValueMapper {
    onFillColorChanged(oldValue: Color, newValue: Color, series: CandlestickSeries): void;
    onFillColorsChanged(oldValue: Color[], newValue: Color[], series: CandlestickSeries): void;
}
export declare class BubbleSeriesValueMapper extends CategoricalSeriesValueMapper {
    onBubbleSizePropertyChanged(oldValue: string, newValue: string, series: BubbleSeries): void;
    onBubbleScalePropertyChanged(oldValue: number, newValue: number, series: BubbleSeries): void;
}
