import { ObservableArray, ChangedData, Color } from '@nativescript/core';
import { RadChartBase } from '../common';
import { ChartSeries, CartesianSeries, CategoricalSeries, PieSeries, BarSeries, DonutSeries, RangeBarSeries, BubbleSeries, OhlcSeries, ScatterSeries, ScatterBubbleSeries } from '../visualization/views/chart-series.common';
import { CartesianAxis, CategoricalAxis } from '../visualization/views/chart-axis.common';
import { RadLegendView } from '../visualization/views/chart-legend-view.common';
import { Palette } from '../visualization/parts/chart-palette.common';
import { ChartAxisHorizontalLocation, ChartAxisVerticalLocation, ChartAxisPlotMode } from '../misc/chart-public-enum';
import { PointLabelStyle } from '../visualization/parts/chart-label-style.common';
export interface ChartBaseValueMapper {
    onLegendChanged(oldValue: RadLegendView, newValue: RadLegendView, chart: RadChartBase): void;
    onPalettesChanged(data: ChangedData<any>, chart: RadChartBase): void;
    onPalettesPropertyChanged(oldValue: ObservableArray<Palette>, newValue: ObservableArray<Palette>, chart: RadChartBase): void;
    onSeriesChanged(data: ChangedData<any>, chart: RadChartBase): void;
    onSeriesPropertyChanged(oldValue: ObservableArray<any>, newValue: ObservableArray<any>, chart: RadChartBase): void;
    onAnnotationsChanged(data: ChangedData<any>, chart: RadChartBase): void;
    onAnnotationsPropertyChanged(oldValue: ObservableArray<any>, newValue: ObservableArray<any>, chart: RadChartBase): void;
    loadSeries(chart: RadChartBase): void;
    loadAnnotations(chart: RadChartBase): void;
    reloadPalettes(chart: RadChartBase): void;
}
export interface ChartSeriesValueMapper {
    onLegendTitleChanged(newValue: string, series: ChartSeries): void;
    onFontInternalChanged(oldValue: any, newValue: any, series: ChartSeries): void;
    onItemsChanged(oldValue: any, newValue: any, series: ChartSeries): void;
    onValuePropertyChanged(oldValue: any, newValue: any, series: ChartSeries): void;
    onShowLabelsChanged(oldValue: boolean, newValue: boolean, series: ChartSeries): void;
    onLabelStyleChanged(oldValue: PointLabelStyle, newValue: PointLabelStyle, series: ChartSeries): void;
    onSelectionModeChanged(oldValue: string, newValue: string, series: ChartSeries): void;
    applyLabelStyle(series: ChartSeries, chart?: RadChartBase): void;
    onLabelPaddingChanged(newValue: number, propertyName: string, series: ChartSeries): void;
}
export interface CartesianSeriesValueMapper extends ChartSeriesValueMapper {
    onHorizontalAxisChanged(oldValue: CartesianAxis, newValue: CartesianAxis, series: CartesianSeries): void;
    onVerticalAxisChanged(oldValue: CartesianAxis, newValue: CartesianAxis, series: CartesianSeries): void;
    onPaletteModeChanged(oldValue: string, newValue: string, series: CartesianSeries): void;
    onFillColorChanged(oldValue: Color, newValue: Color, series: CartesianSeries): void;
    onStrokeWidthChanged(oldValue: number, newValue: number, series: CartesianSeries): void;
    onStrokeColorChanged(oldValue: Color, newValue: Color, series: CartesianSeries): void;
}
export interface CategoricalSeriesValueMapper extends CartesianSeriesValueMapper {
    onCategoryPropertyChanged(oldValue: string, newValue: string, series: CategoricalSeries): void;
    onStackModePropertyChanged(oldValue: string, newValue: string, series: CategoricalSeries): void;
    updateNative(series: CategoricalSeries): void;
}
export interface SplineSeriesValueMapper extends LineSeriesValueMapper {
}
export interface PieSeriesValueMapper extends ChartSeriesValueMapper {
    onLabelPropertyChanged(oldValue: string, newValue: string, series: PieSeries): void;
    onExpandRadiusChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onOuterRadiusFactorChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onStartAngleChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onEndAngleChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onShowPercentageChanged(oldValue: boolean, newValue: boolean, series: PieSeries): void;
    onFillColorsChanged(oldValue: Color[], newValue: Color[], series: PieSeries): void;
    onStrokeWidthChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onStrokeColorsChanged(oldValue: Color[], newValue: Color[], series: PieSeries): void;
}
export interface DonutSeriesValueMapper extends PieSeriesValueMapper {
    onInnerRadiusFactorChanged(oldValue: any, newValue: any, series: DonutSeries): void;
}
export interface BarSeriesValueMapper extends CategoricalSeriesValueMapper {
    onMinBarSizeChanged(oldValue: number, newValue: number, series: BarSeries): void;
    onMaxBarSizeChanged(oldValue: number, newValue: number, series: BarSeries): void;
}
export interface RangeBarSeriesValueMapper extends CategoricalSeriesValueMapper {
    onHighPropertyNameChanged(oldValue: string, newValue: string, series: RangeBarSeries): void;
    onLowPropertyNameChanged(oldValue: string, newValue: string, series: RangeBarSeries): void;
}
export interface LineSeriesValueMapper extends CategoricalSeriesValueMapper {
}
export interface BubbleSeriesValueMapper extends CategoricalSeriesValueMapper {
    onBubbleSizePropertyChanged(oldValue: string, newValue: string, series: BubbleSeries): void;
    onBubbleScalePropertyChanged(oldValue: number, newValue: number, series: BubbleSeries): void;
}
export interface CartesianAxisValueMapper {
    onLineHiddenChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    onLineThicknessChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onLineColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onLabelTextColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onLabelBackgroundColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onLabelBorderColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onLabelBorderWidthChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onLabelMarginChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onLabelRotationAngleChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onLabelFitModeChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onLabelLayoutModeChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onLabelFormatChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onLabelPaddingChanged(newValue: number, propertyName: string, axis: CartesianAxis): void;
    onFontInternalChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onHorizontalLocationChanged(oldValue: ChartAxisHorizontalLocation, newValue: ChartAxisHorizontalLocation, axis: CartesianAxis): void;
    onVerticalLocationChanged(oldValue: ChartAxisVerticalLocation, newValue: ChartAxisVerticalLocation, axis: CartesianAxis): void;
    onLabelSizeChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onAllowZoomChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    onAllowPanChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    onHiddenChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    onTicksHiddenChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    onTicksThicknessChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onTicksOffsetChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onTicksLengthChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onTicksColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
}
export interface CategoricalAxisValueMapper extends CartesianAxisValueMapper {
    onMajorTickIntervalChanged(oldValue: number, newValue: number, axis: CategoricalAxis): void;
    onPlotModeChanged(oldValue: ChartAxisPlotMode, newValue: ChartAxisPlotMode, axis: CategoricalAxis): void;
    onLastLabelVisibilityChanged(oldValue: string, newValue: string, axis: CategoricalAxis): void;
    onFirstLabelVisibilityChanged(oldValue: string, newValue: string, axis: CategoricalAxis): void;
}
export interface OhlcSeriesValueMapper extends CategoricalSeriesValueMapper {
    onHighPropertyNameChanged(oldValue: string, newValue: string, series: OhlcSeries): void;
    onLowPropertyNameChanged(oldValue: string, newValue: string, series: OhlcSeries): void;
    onOpenPropertyNameChanged(oldValue: string, newValue: string, series: OhlcSeries): void;
    onClosePropertyNameChanged(oldValue: string, newValue: string, series: OhlcSeries): void;
    onStrokeColorsChanged(oldValue: Color[], newValue: Color[], series: OhlcSeries): void;
}
export interface CandlestickSeriesValueMapper extends OhlcSeriesValueMapper {
    onFillColorsChanged(oldValue: Color[], newValue: Color[], series: OhlcSeries): void;
}
export interface ScatterSeriesValueMapper extends CartesianSeriesValueMapper {
    onXPropertyChanged(oldValue: string, newValue: string, series: ScatterSeries): void;
    onYPropertyChanged(oldValue: string, newValue: string, series: ScatterSeries): void;
}
export interface ScatterBubbleSeriesValueMapper extends ScatterSeriesValueMapper {
    onBubbleSizePropertyChanged(oldValue: string, newValue: string, series: ScatterBubbleSeries): void;
    onBubbleScaleChanged(oldValue: number, newValue: number, series: ScatterBubbleSeries): void;
}
