import { Color, ObservableArray, ChangedData } from '@nativescript/core';
import * as chartCommonModule from '../common';
import * as chartInitializersCommon from '../initializers/chart-initializers.common';
import { CartesianAxis, CategoricalAxis } from '../visualization/views/chart-axis.common';
import { PointLabelStyle } from '../visualization/parts/chart-label-style.common';
import { ChartAxisLabelFitMode, ChartAxisLabelLayoutMode, ChartAxisHorizontalLocation, ChartAxisVerticalLocation, ChartAxisPlotMode, ChartAxisLabelVisibility } from '../misc/chart-public-enum';
import { BarSeries, ChartSeries, CartesianSeries, CategoricalSeries, RangeBarSeries, PieSeries, DonutSeries, BubbleSeries, ScatterSeries, ScatterBubbleSeries, OhlcSeries, CandlestickSeries } from '../visualization/views/chart-series.common';
import { BarSeries as IosBarSeries } from '../visualization/views/chart-series.ios';
import { RadLegendView } from '../visualization/views/chart-legend-view.common';
import { Palette } from '../visualization/parts/chart-palette.common';
export declare class ChartBaseValueMapper implements chartInitializersCommon.ChartBaseValueMapper {
    onLegendChanged(oldValue: RadLegendView, newValue: RadLegendView, chart: chartCommonModule.RadChartBase): void;
    onPalettesChanged(data: ChangedData<any>, chart: chartCommonModule.RadChartBase): void;
    onPalettesPropertyChanged(oldValue: ObservableArray<Palette>, newValue: ObservableArray<Palette>, chart: chartCommonModule.RadChartBase): void;
    onSeriesChanged(data: ChangedData<any>, chart: chartCommonModule.RadChartBase): void;
    onSeriesPropertyChanged(oldValue: ObservableArray<any>, newValue: ObservableArray<any>, chart: chartCommonModule.RadChartBase): void;
    onAnnotationsChanged(data: ChangedData<any>, chart: chartCommonModule.RadChartBase): void;
    onAnnotationsPropertyChanged(oldValue: ObservableArray<any>, newValue: ObservableArray<any>, chart: chartCommonModule.RadChartBase): void;
    onSelectionModeChanged(oldValue: string, newValue: string, chart: chartCommonModule.RadChartBase): void;
    loadSeries(chart: chartCommonModule.RadChartBase): void;
    loadAnnotations(chart: chartCommonModule.RadChartBase): void;
    reloadPalettes(chart: chartCommonModule.RadChartBase): void;
}
export declare class CartesianAxisValueMapper implements chartInitializersCommon.CartesianAxisValueMapper {
    onLineThicknessChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onLineColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onLineHiddenChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    onLabelTextColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onLabelBackgroundColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onLabelBorderColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onLabelBorderWidthChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onLabelMarginChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onLabelRotationAngleChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onLabelFitModeChanged(oldValue: ChartAxisLabelFitMode, newValue: ChartAxisLabelFitMode, axis: CartesianAxis): void;
    onLabelLayoutModeChanged(oldValue: ChartAxisLabelLayoutMode, newValue: ChartAxisLabelLayoutMode, axis: CartesianAxis): void;
    onLabelFormatChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onTicksHiddenChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    onTicksThicknessChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onTicksLengthChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onTicksOffsetChanged(oldValue: number, newValue: number, axis: CartesianAxis): void;
    onTicksColorChanged(oldValue: Color, newValue: Color, axis: CartesianAxis): void;
    onHorizontalLocationChanged(oldValue: ChartAxisHorizontalLocation, newValue: ChartAxisHorizontalLocation, axis: CartesianAxis): void;
    onVerticalLocationChanged(oldValue: ChartAxisVerticalLocation, newValue: ChartAxisVerticalLocation, axis: CartesianAxis): void;
    onFontInternalChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onLabelPaddingChanged(newValue: number, propertyName: string, axis: CartesianAxis): void;
    onLabelSizeChanged(oldValue: any, newValue: any, axis: CartesianAxis): void;
    onAllowZoomChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    onAllowPanChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
    onHiddenChanged(oldValue: boolean, newValue: boolean, axis: CartesianAxis): void;
}
export declare class CategoricalAxisValueMapper extends CartesianAxisValueMapper implements chartInitializersCommon.CategoricalAxisValueMapper {
    onMajorTickIntervalChanged(oldValue: number, newValue: number, axis: CategoricalAxis): void;
    onPlotModeChanged(oldValue: ChartAxisPlotMode, newValue: ChartAxisPlotMode, axis: CategoricalAxis): void;
    onLastLabelVisibilityChanged(oldValue: ChartAxisLabelVisibility, newValue: ChartAxisLabelVisibility, axis: CategoricalAxis): void;
    onFirstLabelVisibilityChanged(oldValue: ChartAxisLabelVisibility, newValue: ChartAxisLabelVisibility, axis: CategoricalAxis): void;
}
export declare class ChartSeriesValueMapper implements chartInitializersCommon.ChartSeriesValueMapper {
    onItemsChanged(oldValue: any, newValue: any, series: ChartSeries): void;
    onValuePropertyChanged(oldValue: any, newValue: any, series: ChartSeries): void;
    onShowLabelsChanged(oldValue: boolean, newValue: boolean, series: ChartSeries): void;
    onLegendTitleChanged(newValue: string, series: ChartSeries): void;
    onSelectionModeChanged(oldValue: string, newValue: string, series: ChartSeries): void;
    onLabelPaddingChanged(newValue: number, propertyName: string, series: ChartSeries): void;
    onFontInternalChanged(oldValue: any, newValue: any, series: ChartSeries): void;
    applySelectionMode(series: ChartSeries): void;
    onLabelStyleChanged(oldValue: any, newValue: any, series: ChartSeries): void;
    applyLabelFontFromStyle(series: ChartSeries): void;
    applyLabelInsetsFromStyle(series: ChartSeries): void;
    applyLabelStyle(series: ChartSeries): void;
    protected seriesCanBeBound(series: ChartSeries): any;
}
export declare class PieSeriesValueMapper extends ChartSeriesValueMapper implements chartInitializersCommon.PieSeriesValueMapper {
    onShowLabelsChanged(oldValue: boolean, newValue: boolean, series: PieSeries): void;
    onValuePropertyChanged(oldValue: any, newValue: any, series: PieSeries): void;
    onItemsChanged(oldValue: any, newValue: any, series: PieSeries): void;
    onLabelPropertyChanged(oldValue: string, newValue: string, series: PieSeries): void;
    onLabelStyleChanged(oldValue: PointLabelStyle, newValue: PointLabelStyle, series: PieSeries): void;
    onExpandRadiusChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onOuterRadiusFactorChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onShowPercentageChanged(oldValue: boolean, newValue: boolean, series: PieSeries): void;
    onStartAngleChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onEndAngleChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onLegendTitleChanged(newValue: string, series: ChartSeries): void;
    onFillColorsChanged(oldValue: Color[], newValue: Color[], series: PieSeries): void;
    onStrokeWidthChanged(oldValue: number, newValue: number, series: PieSeries): void;
    onStrokeColorsChanged(oldValue: Color[], newValue: Color[], series: PieSeries): void;
    private applyFills;
    private applyStrokes;
    protected applyColors(series: PieSeries): void;
    protected getNativeData(series: PieSeries): NSMutableArray<any>;
    protected setCommonProperties(series: PieSeries): void;
    protected seriesCanBeBound(series: PieSeries): any;
    protected bind(series: PieSeries): void;
}
export declare class DonutSeriesValueMapper extends PieSeriesValueMapper {
    onInnerRadiusFactorChanged(oldValue: any, newValue: any, series: DonutSeries): void;
    protected bind(series: DonutSeries): void;
}
export declare class CartesianSeriesValueMapper extends ChartSeriesValueMapper implements chartInitializersCommon.CartesianSeriesValueMapper {
    onHorizontalAxisChanged(oldValue: CartesianAxis, newValue: CartesianAxis, series: CartesianSeries): void;
    onVerticalAxisChanged(oldValue: CartesianAxis, newValue: CartesianAxis, series: CartesianSeries): void;
    onPaletteModeChanged(oldValue: string, newValue: string, series: CartesianSeries): void;
    protected applyPaletteMode(series: CartesianSeries): void;
    onFillColorChanged(oldValue: Color, newValue: Color, series: CartesianSeries): void;
    onStrokeWidthChanged(oldValue: number, newValue: number, series: CartesianSeries): void;
    onStrokeColorChanged(oldValue: Color, newValue: Color, series: CartesianSeries): void;
    private applyFillColor;
    private applyStrokeWidth;
    private applyStrokeColor;
    private applyStroke;
    protected applyColors(series: CartesianSeries): void;
    protected updateNativeSeriesAxis(series: CartesianSeries, oldAxis: CartesianAxis, newAxis: CartesianAxis, isVertical: boolean): void;
    protected bindSeriesAxes(series: CartesianSeries): void;
}
export declare class CategoricalSeriesValueMapper extends CartesianSeriesValueMapper implements chartInitializersCommon.CategoricalSeriesValueMapper {
    onCategoryPropertyChanged(oldValue: string, newValue: string, series: CategoricalSeries): void;
    onValuePropertyChanged(oldValue: any, newValue: any, series: CategoricalSeries): void;
    onItemsChanged(oldValue: any, newValue: any, series: CategoricalSeries): void;
    onShowLabelsChanged(oldValue: boolean, newValue: boolean, series: CategoricalSeries): void;
    onStackModePropertyChanged(oldValue: string, newValue: string, series: CategoricalSeries): void;
    onLabelStyleChanged(oldValue: PointLabelStyle, newValue: PointLabelStyle, series: CategoricalSeries): void;
    updateNative(series: CategoricalSeries): void;
    protected seriesCanBeBound(series: CategoricalSeries): string;
    protected bind(series: CategoricalSeries): void;
    protected setStackInfo(series: CategoricalSeries): void;
    /**
     *  Cleans the axes from previous data categories if any.
     *  This method should be called if series items collection is changed.
     */
    cleanCategoryAxes(series: ChartSeries): void;
}
export declare class BarSeriesValueMapper extends CategoricalSeriesValueMapper implements chartInitializersCommon.BarSeriesValueMapper {
    onHorizontalAxisChanged(oldValue: CartesianAxis, newValue: CartesianAxis, series: IosBarSeries): void;
    onVerticalAxisChanged(oldValue: CartesianAxis, newValue: CartesianAxis, series: IosBarSeries): void;
    onMinBarSizeChanged(oldValue: number, newValue: number, series: BarSeries): void;
    onMaxBarSizeChanged(oldValue: number, newValue: number, series: BarSeries): void;
    protected seriesCanBeBound(series: CategoricalSeries): any;
    protected bind(series: BarSeries): void;
}
export declare class RangeBarSeriesValueMapper extends CategoricalSeriesValueMapper implements chartInitializersCommon.RangeBarSeriesValueMapper {
    onHorizontalAxisChanged(oldValue: CartesianAxis, newValue: CartesianAxis, series: IosBarSeries): void;
    onVerticalAxisChanged(oldValue: CartesianAxis, newValue: CartesianAxis, series: IosBarSeries): void;
    onHighPropertyNameChanged(oldValue: string, newValue: string, series: RangeBarSeries): void;
    onLowPropertyNameChanged(oldValue: string, newValue: string, series: RangeBarSeries): void;
    protected seriesCanBeBound(series: RangeBarSeries): string;
    protected bind(series: RangeBarSeries): void;
}
export declare class LineSeriesValueMapper extends CategoricalSeriesValueMapper implements chartInitializersCommon.CategoricalSeriesValueMapper {
    protected getDataPointsForSeries(series: CategoricalSeries): NSMutableArray<any>;
    protected applyPaletteMode(series: CartesianSeries): void;
    protected seriesCanBeBound(series: CategoricalSeries): any;
    protected bind(series: CategoricalSeries): void;
}
export declare class SplineSeriesValueMapper extends LineSeriesValueMapper {
    protected bind(series: CategoricalSeries): void;
}
export declare class AreaSeriesValueMapper extends LineSeriesValueMapper {
    protected bind(series: CategoricalSeries): void;
}
export declare class SplineAreaSeriesValueMapper extends AreaSeriesValueMapper {
    protected bind(series: CategoricalSeries): void;
}
export declare class BubbleSeriesValueMapper extends CategoricalSeriesValueMapper implements chartInitializersCommon.BubbleSeriesValueMapper {
    onBubbleSizePropertyChanged(oldValue: string, newValue: string, series: BubbleSeries): void;
    onBubbleScalePropertyChanged(oldValue: number, newValue: number, series: BubbleSeries): void;
    protected seriesCanBeBound(series: BubbleSeries): string;
    protected bind(series: BubbleSeries): void;
}
export declare class OhlcSeriesValueMapper extends CategoricalSeriesValueMapper implements chartInitializersCommon.OhlcSeriesValueMapper {
    onHighPropertyNameChanged(oldValue: string, newValue: string, series: OhlcSeries): void;
    onLowPropertyNameChanged(oldValue: string, newValue: string, series: OhlcSeries): void;
    onOpenPropertyNameChanged(oldValue: string, newValue: string, series: OhlcSeries): void;
    onClosePropertyNameChanged(oldValue: string, newValue: string, series: OhlcSeries): void;
    onValuePropertyChanged(oldValue: any, newValue: any, series: OhlcSeries): void;
    onStrokeColorsChanged(oldValue: Color[], newValue: Color[], series: OhlcSeries): void;
    protected applyColors(series: OhlcSeries): void;
    private applyStrokes;
    protected seriesCanBeBound(series: OhlcSeries): string;
    protected bind(series: OhlcSeries): void;
}
export declare class CandlestickSeriesValueMapper extends OhlcSeriesValueMapper {
    protected bind(series: CandlestickSeries): void;
    onFillColorsChanged(oldValue: Color[], newValue: Color[], series: CandlestickSeries): void;
    protected applyColors(series: CandlestickSeries): void;
    private applyFills;
}
export declare class ScatterSeriesValueMapper extends CartesianSeriesValueMapper implements chartInitializersCommon.ScatterSeriesValueMapper {
    onXPropertyChanged(oldValue: string, newValue: string, series: ScatterSeries): void;
    onYPropertyChanged(oldValue: string, newValue: string, series: ScatterSeries): void;
    onItemsChanged(oldValue: any, newValue: any, series: ScatterSeries): void;
    protected seriesCanBeBound(series: ScatterSeries): string;
    protected bind(series: ScatterSeries): void;
}
export declare class ScatterBubbleSeriesValueMapper extends ScatterSeriesValueMapper implements chartInitializersCommon.ScatterBubbleSeriesValueMapper {
    onBubbleSizePropertyChanged(oldValue: string, newValue: string, series: ScatterBubbleSeries): void;
    onBubbleScaleChanged(oldValue: number, newValue: number, series: ScatterBubbleSeries): void;
    protected seriesCanBeBound(series: ScatterBubbleSeries): string;
    protected bind(series: ScatterBubbleSeries): void;
}
