import { View, Property, Color } from '@nativescript/core';
import * as initializersCommon from '../../initializers/chart-initializers.common';
import { ChartAxisLabelVisibility, ChartAxisDateTimeComponent, ChartAxisLabelFitMode, ChartAxisLabelLayoutMode, ChartAxisVerticalLocation, ChartAxisHorizontalLocation, ChartAxisPlotMode } from '../../misc/chart-public-enum';
/**
 * Represents an axis in a Cartesian chart. This class is a base class for all
 * axes that can be used within a RadCartesianChart instance.
 */
export declare class CartesianAxis extends View {
    protected _initializer: initializersCommon.CartesianAxisValueMapper;
    private _label;
    private _labelPropertyChangeHandler;
    id: string;
    lineColor: Color;
    lineThickness: number;
    lineHidden: boolean;
    labelTextColor: Color;
    labelBackgroundColor: Color;
    labelBorderColor: Color;
    labelBorderWidth: number;
    labelSize: any;
    labelFormat: any;
    labelMargin: any;
    labelRotationAngle: any;
    labelFitMode: ChartAxisLabelFitMode;
    labelLayoutMode: ChartAxisLabelLayoutMode;
    horizontalLocation: ChartAxisHorizontalLocation;
    verticalLocation: ChartAxisVerticalLocation;
    ticksThickness: number;
    ticksLength: number;
    ticksOffset: number;
    ticksHidden: boolean;
    ticksColor: Color;
    allowPan: boolean;
    allowZoom: boolean;
    hidden: boolean;
    static idProperty: Property<CartesianAxis, string>;
    static lineColorProperty: Property<CartesianAxis, Color>;
    private onLineColorPropertyChanged;
    protected onLineColorChanged(oldValue: Color, newValue: Color): void;
    static lineThicknessProperty: Property<CartesianAxis, number>;
    private onLineThicknessPropertyChanged;
    protected onLineThicknessChanged(oldValue: number, newValue: number): void;
    static lineHiddenProperty: Property<CartesianAxis, boolean>;
    private onLineHiddenPropertyChanged;
    protected onLineHiddenChanged(oldValue: boolean, newValue: boolean): void;
    static labelTextColorProperty: Property<CartesianAxis, Color>;
    private onLabelTextColorPropertyChanged;
    protected onLabelTextColorChanged(oldValue: Color, newValue: Color): void;
    static labelBackgroundColorProperty: Property<CartesianAxis, Color>;
    private onLabelBackgroundColorPropertyChanged;
    protected onLabelBackgroundColorChanged(oldValue: Color, newValue: Color): void;
    static labelBorderColorProperty: Property<CartesianAxis, Color>;
    private onLabelBorderColorPropertyChanged;
    protected onLabelBorderColorChanged(oldValue: Color, newValue: Color): void;
    static labelBorderWidthProperty: Property<CartesianAxis, number>;
    private onLabelBorderWidthPropertyChanged;
    protected onLabelBorderWidthChanged(oldValue: number, newValue: number): void;
    /**
     * Identifies the labelSize dependency property.
     */
    static labelSizeProperty: Property<CartesianAxis, any>;
    private onLabelSizePropertyChanged;
    /**
     * Called when the labelSize property changes.
     * @param data an object containing information about the change event.
     */
    protected onLabelSizeChanged(oldValue: any, newValue: any): void;
    /**
     * Identifies labelFormat dependency property.
     */
    static labelFormatProperty: Property<CartesianAxis, any>;
    private onLabelFormatPropertyChanged;
    /**
     * Called when the labelFormat property changes.
     * @param data an object containing information about the change event.
     */
    protected onLabelFormatChanged(oldValue: any, newValue: any): void;
    /**
     * Identifies the labelMargin dependency property.
     */
    static labelMarginProperty: Property<CartesianAxis, number>;
    private onLabelMarginPropertyChanged;
    /**
     * Called when the labelMargin property changes.
     * @param data an object containing information about the change event.
     */
    protected onLabelMarginChanged(oldValue: any, newValue: number): void;
    /**
     * Identifies the labelRotationAngle dependency property.
     */
    static labelRotationAngleProperty: Property<CartesianAxis, number>;
    private onLabelRotationAnglePropertyChanged;
    /**
     * Called when the labelRotationAngle property changes.
     * @param data an object containing information about the change event.
     */
    protected onLabelRotationAngleChanged(oldValue: number, newValue: number): void;
    /**
     * Identifies the labelFitMode dependency property.
     */
    static labelFitModeProperty: Property<CartesianAxis, ChartAxisLabelFitMode>;
    private onLabelFitModePropertyChanged;
    /**
     * Called when the labelFitMode property changes.
     * @param data an object containing information about the change event.
     */
    protected onLabelFitModeChanged(oldValue: any, newValue: any): void;
    /**
     * Identifies the labelLayoutMode dependency property.
     */
    static labelLayoutModeProperty: Property<CartesianAxis, ChartAxisLabelLayoutMode>;
    private onLabelLayoutModePropertyChanged;
    /**
     * Called when the labelLayoutMode property changes.
     * @param data an object containing information about the change event.
     */
    protected onLabelLayoutModeChanged(oldValue: any, newValue: any): void;
    static ticksThicknessProperty: Property<CartesianAxis, number>;
    private onTicksThicknessPropertyChanged;
    protected onTicksThicknessChanged(oldValue: number, newValue: number): void;
    static ticksLengthProperty: Property<CartesianAxis, number>;
    private onTicksLengthPropertyChanged;
    protected onTicksLengthChanged(oldValue: number, newValue: number): void;
    static ticksOffsetProperty: Property<CartesianAxis, number>;
    private onTicksOffsetPropertyChanged;
    protected onTicksOffsetChanged(oldValue: number, newValue: number): void;
    static ticksHiddenProperty: Property<CartesianAxis, boolean>;
    private onTicksHiddenPropertyChanged;
    protected onTicksHiddenChanged(oldValue: boolean, newValue: boolean): void;
    static ticksColorProperty: Property<CartesianAxis, Color>;
    private onTicksColorPropertyChanged;
    protected onTicksColorChanged(oldValue: Color, newValue: Color): void;
    /**
     * Identifies the horizontalLocation dependency property.
     */
    static horizontalLocationProperty: Property<CartesianAxis, ChartAxisHorizontalLocation>;
    private onHorizontalLocationPropertyChanged;
    /**
     * Called when the horizontalLocation property changes.
     * @param data an object containing information about the change event.
     */
    protected onHorizontalLocationChanged(oldValue: ChartAxisHorizontalLocation, newValue: ChartAxisHorizontalLocation): void;
    /**
     * Identifies the verticalLocation dependency property.
     */
    static verticalLocationProperty: Property<CartesianAxis, ChartAxisVerticalLocation>;
    private onVerticalLocationPropertyChanged;
    /**
     * Called when the verticalLocation property changes.
     */
    protected onVerticalLocationChanged(oldValue: ChartAxisVerticalLocation, newValue: ChartAxisVerticalLocation): void;
    /**
     * Identifies the allowPan dependency property.
     */
    static allowPanProperty: Property<CartesianAxis, boolean>;
    private onAllowPanPropertyChanged;
    /**
     * Called when the allowPan property changes.
     */
    protected onAllowPanChanged(oldValue: boolean, newValue: boolean): void;
    /**
     * Identifies the allowZoom dependency property.
     */
    static allowZoomProperty: Property<CartesianAxis, boolean>;
    private onAllowZoomPropertyChanged;
    /**
     * Called when the allowZoom property changes.
     */
    protected onAllowZoomChanged(oldValue: boolean, newValue: boolean): void;
    /**
     * Identifies the hidden dependency property.
     */
    static hiddenProperty: Property<CartesianAxis, boolean>;
    private onHiddenPropertyChanged;
    /**
     * Called when the hidden property changes.
     */
    protected onHiddenChanged(oldValue: boolean, newValue: boolean): void;
    eachChild(callback: (child: View) => boolean): void;
    get label(): ChartAxisLabel;
    onLoaded(): void;
    onUnloaded(): void;
    updateLabelColorFromStyle(): void;
    private updateLabelFontFromStyle;
    private updateLabelMarginFromStyle;
    private updateLabelFitModeFromStyle;
    private updateLabelLayoutModeFromStyle;
    private updateLabelRotationAngleFromStyle;
    private updateLabelFormatFromStyle;
    private updateLabelPaddingFromStyle;
    updateLabelBackgroundColorFromStyle(): void;
    updateLabelBorderWidthFromStyle(): void;
    updateLabelBorderColorFromStyle(): void;
    private applyLabelPropertyFromStyle;
    private attachLabelChangeListeners;
    private detachLabelChangeListeners;
    protected get initializer(): initializersCommon.CartesianAxisValueMapper;
    get android(): any;
    get ios(): any;
    /**
     *  Keeps instance to owner chart in iOS and chart or series for Android
     */
    private _owner;
    get owner(): any;
    set owner(value: any);
    update(): void;
}
export declare class CategoricalAxis extends CartesianAxis {
    majorTickInterval: number;
    plotMode: ChartAxisPlotMode;
    static majorTickIntervalProperty: Property<CategoricalAxis, number>;
    private onMajorTickIntervalPropertyChanged;
    static plotModeProperty: Property<CategoricalAxis, ChartAxisPlotMode>;
    private onPlotModePropertyChanged;
    static lastLabelVisibilityProperty: Property<CategoricalAxis, ChartAxisLabelVisibility>;
    private onLastLabelVisibilityPropertyChanged;
    static firstLabelVisibilityProperty: Property<CategoricalAxis, ChartAxisLabelVisibility>;
    private onFirstLabelVisibilityPropertyChanged;
    protected get initializer(): initializersCommon.CategoricalAxisValueMapper;
    protected onMajorTickIntervalChanged(oldValue: number, newValue: number): void;
    protected onPlotModeChanged(oldValue: ChartAxisPlotMode, newValue: ChartAxisPlotMode): void;
    protected onLastLabelVisibilityChanged(oldValue: string, newValue: string): void;
    protected onFirstLabelVisibilityChanged(oldValue: string, newValue: string): void;
}
export declare class LinearAxis extends CartesianAxis {
    majorStep: number;
    maximum: number;
    minimum: number;
    static majorStepProperty: Property<LinearAxis, number>;
    static minimumProperty: Property<LinearAxis, any>;
    static maximumProperty: Property<LinearAxis, any>;
    private onMinimumPropertyChanged;
    protected onMinimumChanged(oldValue: number, newValue: number): void;
    private onMaximumPropertyChanged;
    protected onMaximumChanged(oldValue: number, newValue: number): void;
    private onMajorStepPropertyChanged;
    protected onMajorStepChanged(oldValue: number, newValue: number): void;
}
export declare class DateTimeContinuousAxis extends LinearAxis {
    plotMode: ChartAxisPlotMode;
    dateFormat: string;
    sourceDateFormat: string;
    majorStepUnit: ChartAxisDateTimeComponent;
    static plotModeProperty: Property<DateTimeContinuousAxis, ChartAxisPlotMode>;
    static dateFormatProperty: Property<DateTimeContinuousAxis, string>;
    static sourceDateFormatProperty: Property<DateTimeContinuousAxis, string>;
    static majorStepUnitProperty: Property<DateTimeContinuousAxis, ChartAxisDateTimeComponent>;
    private onPlotModePropertyChanged;
    private onDateFormatPropertyChanged;
    private onSourceDateFormatPropertyChanged;
    protected onPlotModeChanged(oldValue: ChartAxisPlotMode, newValue: ChartAxisPlotMode): void;
    protected onDateFormatChanged(oldValue: string, newValue: string): void;
    protected onSourceDateFormatChanged(oldValue: string, newValue: string): void;
    private onMajorStepUnitPropertyChanged;
    protected onMajorStepUnitChanged(oldValue: ChartAxisDateTimeComponent, newValue: ChartAxisDateTimeComponent): void;
}
export declare class DateTimeCategoricalAxis extends CategoricalAxis {
    dateTimeComponent: string;
    dateFormat: string;
    static dateTimeComponentProperty: Property<DateTimeCategoricalAxis, string>;
    static dateFormatProperty: Property<DateTimeCategoricalAxis, string>;
    private onDateTimeComponentPropertyChanged;
    private onDateFormatPropertyChanged;
    protected onDateTimeComponentChanged(oldValue: string, newValue: string): void;
    protected onDateFormatChanged(oldValue: string, newValue: string): void;
    get android(): any;
    get ios(): any;
}
export declare class LogarithmicAxis extends LinearAxis {
    exponentStep: number;
    logarithmBase: number;
    static exponentStepProperty: Property<LogarithmicAxis, number>;
    static logarithmBaseProperty: Property<LogarithmicAxis, number>;
    private onExponentStepPropertyChanged;
    private onLogarithmBasePropertyChanged;
    protected onExponentStepChanged(oldValue: number, newValue: number): void;
    protected onLogarithmBaseChanged(oldValue: number, newValue: number): void;
    get android(): any;
    get ios(): any;
}
export declare class ChartAxisLabel extends View {
    fitMode: ChartAxisLabelFitMode;
    layoutMode: ChartAxisLabelLayoutMode;
    rotationAngle: number;
    format: string;
    static fitModeProperty: Property<ChartAxisLabel, ChartAxisLabelFitMode>;
    static layoutModeProperty: Property<ChartAxisLabel, ChartAxisLabelLayoutMode>;
    static rotationAngleProperty: Property<ChartAxisLabel, number>;
    static formatProperty: Property<ChartAxisLabel, string>;
}
export declare function trimQuotes(value: string): string;
