import { View, Property, Color } from '@nativescript/core';
import { RadChartBase, RadCartesianChart, RadPieChart } from '../../common';
import * as initializersCommon from '../../initializers/chart-initializers.common';
import { CartesianAxis } from './chart-axis.common';
import { ChartSeriesSelectionMode, ChartSeriesStackMode, ChartSeriesPaletteMode } from '../../misc/chart-public-enum';
import { PointLabelStyle } from '../parts/chart-label-style.common';
export declare class ChartSeries extends View {
    seriesName: string;
    protected _initializer: initializersCommon.ChartSeriesValueMapper;
    selectionMode: ChartSeriesSelectionMode;
    labelStyle: PointLabelStyle;
    showLabels: boolean;
    legendTitle: string;
    valueProperty: any;
    items: any;
    private _label;
    private _labelPropertyChangeHandler;
    constructor();
    initNativeView(): void;
    eachChild(callback: (child: View) => boolean): void;
    onLoaded(): void;
    get label(): ChartSeriesLabel;
    updateLabelColorFromStyle(): void;
    private updateLabelFontFromStyle;
    private updateLabelMarginFromStyle;
    private updateLabelFillColorFromStyle;
    private updateLabelStrokeWidthFromStyle;
    private updateLabelStrokeColorFromStyle;
    private updateLabelFormatFromStyle;
    private updateLabelPaddingFromStyle;
    private applyLabelPropertyFromStyle;
    private attachLabelChangeListeners;
    private detachLabelChangeListeners;
    onUnloaded(): void;
    static selectionModeProperty: Property<ChartSeries, ChartSeriesSelectionMode>;
    static labelStyleProperty: Property<ChartSeries, PointLabelStyle>;
    static showLabelsProperty: Property<ChartSeries, boolean>;
    static legendTitleProperty: Property<ChartSeries, string>;
    static valuePropertyProperty: Property<ChartSeries, any>;
    static itemsProperty: Property<ChartSeries, any>;
    protected get initializer(): initializersCommon.ChartSeriesValueMapper;
    get owner(): RadChartBase;
    set owner(value: RadChartBase);
    updateOwnerChart(): void;
    get android(): any;
    get ios(): any;
    set ios(value: any);
    private onLegendTitlePropertyChanged;
    private onItemsPropertyChanged;
    private onValuePropertyPropertyChanged;
    private onShowLabelsPropertyChanged;
    private onLabelStylePropertyChanged;
    private onSelectionModePropertyChanged;
    protected onSelectionModeChanged(oldValue: ChartSeriesSelectionMode, newValue: ChartSeriesSelectionMode): void;
    protected onLabelStyleChanged(oldValue: PointLabelStyle, newValue: PointLabelStyle): void;
    protected onShowLabelsChanged(oldValue: boolean, newValue: boolean): void;
    protected onLegendTitleChanged(oldValue: string, newValue: string): void;
    protected onItemsChanged(oldValue: any, newValue: any): void;
    protected ItemsCollectionChangedInternal(data: any): void;
    getItemAtIndex(index: any): any;
    protected onValuePropertyChanged(oldValue: any, newValue: any): void;
}
export declare class CartesianSeries extends ChartSeries {
    horizontalAxis: CartesianAxis;
    verticalAxis: CartesianAxis;
    paletteMode: ChartSeriesPaletteMode;
    fillColor: Color;
    strokeWidth: number;
    strokeColor: Color;
    private _owner;
    get owner(): RadCartesianChart;
    set owner(value: RadCartesianChart);
    eachChild(callback: (child: View) => boolean): void;
    static horizontalAxisProperty: Property<CartesianSeries, CartesianAxis>;
    static verticalAxisProperty: Property<CartesianSeries, CartesianAxis>;
    static paletteModeProperty: Property<CartesianSeries, ChartSeriesPaletteMode>;
    static fillColorProperty: Property<CartesianSeries, Color>;
    static strokeWidthProperty: Property<CartesianSeries, number>;
    static strokeColorProperty: Property<CartesianSeries, Color>;
    private onFillColorPropertyChanged;
    private onStrokeWidthPropertyChanged;
    private onStrokeColorPropertyChanged;
    protected onFillColorChanged(oldValue: Color, newValue: Color): void;
    protected onStrokeWidthChanged(oldValue: number, newValue: number): void;
    protected onStrokeColorChanged(oldValue: Color, newValue: Color): void;
    protected get initializer(): initializersCommon.CartesianSeriesValueMapper;
    private onHorizontalAxisPropertyChanged;
    private onVerticalAxisPropertyChanged;
    protected onHorizontalAxisChanged(oldValue: CartesianAxis, newValue: CartesianAxis): void;
    protected onVerticalAxisChanged(oldValue: CartesianAxis, newValue: CartesianAxis): void;
    protected onPaletteModeChanged(oldValue: any, newValue: any): void;
    private updateAxisBindingContext;
}
export declare class CategoricalSeries extends CartesianSeries {
    stackMode: ChartSeriesStackMode;
    categoryProperty: string;
    static categoryPropertyProperty: Property<CategoricalSeries, string>;
    static stackModeProperty: Property<CategoricalSeries, ChartSeriesStackMode>;
    private onStackModePropertyChanged;
    private onCategoryPropertyChanged;
    protected get initializer(): initializersCommon.CategoricalSeriesValueMapper;
    protected onStackModeChanged(oldValue: ChartSeriesStackMode, newValue: ChartSeriesStackMode): void;
    private onCategoryChanged;
}
export declare class BarSeries extends CategoricalSeries {
    minBarSize: number;
    maxBarSize: number;
    static minBarSizeProperty: Property<BarSeries, number>;
    protected onMinBarSizeChanged(oldValue: any, newValue: any): void;
    static maxBarSizeProperty: Property<BarSeries, number>;
    protected onMaxBarSizeChanged(oldValue: any, newValue: any): void;
    protected get initializer(): initializersCommon.BarSeriesValueMapper;
}
export declare class RangeBarSeries extends CategoricalSeries {
    lowPropertyName: string;
    highPropertyName: string;
    static highPropertyNameProperty: Property<RangeBarSeries, string>;
    private onHighPropertyNamePropertyChanged;
    static lowPropertyNameProperty: Property<RangeBarSeries, string>;
    private onLowPropertyNamePropertyChanged;
    protected onLowPropertyNameChanged(oldValue: string, newValue: string): void;
    protected onHighPropertyNameChanged(oldValue: string, newValue: string): void;
}
export declare class OhlcSeries extends CategoricalSeries {
    lowPropertyName: string;
    highPropertyName: string;
    closePropertyName: string;
    openPropertyName: string;
    strokeColors: Color[];
    static openPropertyNameProperty: Property<OhlcSeries, string>;
    private onOpenPropertyNamePropertyChanged;
    static closePropertyNameProperty: Property<OhlcSeries, string>;
    private onClosePropertyNamePropertyChanged;
    static highPropertyNameProperty: Property<OhlcSeries, string>;
    private onHighPropertyNamePropertyChanged;
    static lowPropertyNameProperty: Property<OhlcSeries, string>;
    private onLowPropertyNamePropertyChanged;
    static strokeColorsProperty: Property<OhlcSeries, Color[]>;
    private onStrokeColorsPropertyChanged;
    protected onLowPropertyNameChanged(oldValue: string, newValue: string): void;
    protected onHighPropertyNameChanged(oldValue: string, newValue: string): void;
    protected onClosePropertyNameChanged(oldValue: string, newValue: string): void;
    protected onOpenPropertyNameChanged(oldValue: string, newValue: string): void;
    protected onStrokeColorsChanged(oldValue: Color[], newValue: Color[]): void;
    protected get initializer(): initializersCommon.OhlcSeriesValueMapper;
}
export declare class CandlestickSeries extends OhlcSeries {
    fillColors: Color[];
}
export declare class BubbleSeries extends CategoricalSeries {
    bubbleScale: number;
    bubbleSizeProperty: string;
    static bubbleScaleProperty: Property<BubbleSeries, number>;
    static bubbleSizePropertyProperty: Property<BubbleSeries, string>;
    private onBubbleScalePropertyChanged;
    protected onBubbleScaleChanged(oldValue: number, newValue: number): void;
    private onBubbleSizePropertyPropertyChanged;
    protected onBubbleSizePropertyChanged(oldValue: string, newValue: string): void;
}
export declare class PieSeries extends ChartSeries {
    legendLabel: any;
    expandRadius: number;
    outerRadiusFactor: number;
    startAngle: number;
    endAngle: number;
    showPercentage: boolean;
    fillColors: Color[];
    strokeWidth: number;
    strokeColors: Color[];
    private _owner;
    get owner(): RadPieChart;
    set owner(value: RadPieChart);
    protected get initializer(): initializersCommon.PieSeriesValueMapper;
    get android(): any;
    get ios(): any;
    set ios(value: any);
    static legendLabelProperty: Property<PieSeries, any>;
    static expandRadiusProperty: Property<PieSeries, number>;
    static outerRadiusFactorProperty: Property<PieSeries, number>;
    static startAngleProperty: Property<PieSeries, number>;
    static endAngleProperty: Property<PieSeries, number>;
    static showPercentageProperty: Property<PieSeries, boolean>;
    static fillColorsProperty: Property<PieSeries, Color[]>;
    static strokeWidthProperty: Property<PieSeries, number>;
    static strokeColorsProperty: Property<PieSeries, Color[]>;
    private onFillColorsPropertyChanged;
    private onStrokeWidthPropertyChanged;
    private onStrokeColorsPropertyChanged;
    protected onFillColorsChanged(oldValue: Color[], newValue: Color[]): void;
    protected onStrokeWidthChanged(oldValue: number, newValue: number): void;
    protected onStrokeColorsChanged(oldValue: Color[], newValue: Color[]): void;
    private onLegendLabelPropertyChanged;
    private onExpandRadiusPropertyChanged;
    private onOuterRadiusFactorPropertyChanged;
    private onStartAnglePropertyChanged;
    private onEndAnglePropertyChanged;
    private onShowPercentagePropertyChanged;
    protected onLegendLabelChanged(oldValue: string, newValue: string): void;
    protected onExpandRadiusChanged(oldValue: number, newValue: number): void;
    protected onOuterRadiusFactorChanged(oldValue: number, newValue: number): void;
    protected onStartAngleChanged(oldValue: number, newValue: number): void;
    protected onEndAngleChanged(oldValue: number, newValue: number): void;
    protected onShowPercentageChanged(oldValue: boolean, newValue: boolean): void;
}
export declare class DonutSeries extends PieSeries {
    innerRadiusFactor: any;
    static innerRadiusFactorProperty: Property<DonutSeries, any>;
    private onInnerRadiusFactorPropertyChanged;
    protected get initializer(): initializersCommon.DonutSeriesValueMapper;
    protected onInnerRadiusFactorChanged(oldValue: any, newValue: any): void;
}
export declare class ScatterSeries extends CartesianSeries {
    xProperty: string;
    yProperty: string;
    static xPropertyProperty: Property<ScatterSeries, string>;
    static yPropertyProperty: Property<ScatterSeries, string>;
    private onXPropertyPropertyChanged;
    private onYPropertyPropertyChanged;
    protected onXPropertyChanged(oldValue: string, newValue: string): void;
    protected onYPropertyChanged(oldValue: string, newValue: string): void;
    protected onValuePropertyChanged(oldValue: string, newValue: string): void;
    protected get initializer(): initializersCommon.ScatterSeriesValueMapper;
}
export declare class ScatterBubbleSeries extends ScatterSeries {
    bubbleScale: number;
    bubbleSizeProperty: string;
    static bubbleScaleProperty: Property<ScatterBubbleSeries, number>;
    static bubbleSizePropertyProperty: Property<ScatterBubbleSeries, string>;
    private onBubbleScalePropertyChanged;
    protected onBubbleScaleChanged(oldValue: number, newValue: number): void;
    private onBubbleSizePropertyPropertyChanged;
    protected onBubbleSizePropertyChanged(oldValue: string, newValue: string): void;
    get initializer(): initializersCommon.ScatterBubbleSeriesValueMapper;
}
export declare class ChartSeriesLabel extends View {
    format: string;
    static formatProperty: Property<ChartSeriesLabel, string>;
}
